@@ -104,21 +104,28 @@ types_converter_dict = {
         },
         "default": {},
     },
-    # toDo remove default values if not cond, varchar(467) - remove numbers for ch
     "pg:ch": {
         "type": {
-            "_text": "Nullable(String)",
-            "text": "Nullable(String)",
-            "jsonb": "Nullable(String)",
-            "json": "Nullable(String)",
-            "varchar": "Nullable(String)",
-            "interval": "Nullable(String)",
-            "int2": "int2",
+            "_text": "String",
+            "text": "String",
+            "jsonb": "String",
+            "json": "String",
+            "varchar": "String",
+            "interval": "String",
+            "character varying": "String",
             "boolean": "UInt8",
-            "int4": "int4",
             "timestamp": "Datetime",
-            "int8": "int8",
+            "timestamp without time zone": "Datetime",
+            "time without time zone": "String",
+            "int2": "Int8",
+            "int4": "Int8",
+            "int8": "Int8",
             "integer": "Int32",
+            "smallint": "Int16",
+            "date": "Date",
+            "bigint": "Int32",
+            "numeric": "Float32",
+            "double precision": "Float64"
         },
         "default": {"false": 0, "true": 1},
     },
