@@ -125,7 +125,7 @@ class FieldsConverter:
         else:
             type_to = type_from
 
-        if column["character_maximum_length"] is not None and type_to not in "text":
+        if column["character_maximum_length"] is not None and type_to not in "text" and self.to_db != 'ch':
             max_length_mult = base_converter_params[self.to_db]["max_length_mult"]
             type_to += "({character_maximum_length})".format(
                 character_maximum_length=int(
@@ -133,7 +133,7 @@ class FieldsConverter:
                 )
             )
             return type_to
-        if column["column_default"] is not None:
+        if column["column_default"] is not None and "::" not in column["column_default"]:
             default_from = column["column_default"].lower()
             if default_from in types_converter_dict[self.key]["default"]:
                 default_to = types_converter_dict[self.key]["default"][default_from]
